@@ -13,12 +13,12 @@ class Client(requests.Session):
         try:
             res = super().request(method, url, verify=self.verify_ssl, timeout=self.request_timeout, *args, **kwargs)
         except Timeout:
-            raise TimeoutException(message=f"Timeout when {method} data to {url}")
+            raise TimeoutException(message=f'Timeout when {method} data to {url}')
 
         if res.status_code == 401:
-            raise UnauthorizedException(message=f"Unauthorized when {method} data to {url}")
+            raise UnauthorizedException(message=f'Unauthorized when {method} data to {url}')
         elif res.status_code == 404:
-            raise NotFoundException(message=f"Not found when {method} data to {url}")
+            raise NotFoundException(message=f'Not found when {method} data to {url}')
         elif res.status_code == 500:
             raise InternalServerErrorException()
         return res
