@@ -14,8 +14,8 @@ class CodeClientSDK(BaseClientSDK):
     def __get_public_keys(self):
         jwks = self.client.get(self.jwks_uri).json()
         public_keys = {}
-        for jwk in jwks.get("keys"):
-            kid = jwk["kid"]
+        for jwk in jwks.get('keys'):
+            kid = jwk['kid']
             public_keys[kid] = jwt.algorithms.RSAAlgorithm.from_jwk(json.dumps(jwk))
 
         self.public_keys = public_keys
@@ -26,62 +26,62 @@ class CodeClientSDK(BaseClientSDK):
         code_verifier = get_random_string()
 
         query_dict = {
-            "response_type": "code",
-            "client_id": self.client_id,
-            "redirect_uri": self.redirect_uri,
-            "scope": " ".join(self.scope),
-            "state": state,
-            "nonce": nonce
+            'response_type': 'code',
+            'client_id': self.client_id,
+            'redirect_uri': self.redirect_uri,
+            'scope': ' '.join(self.scope),
+            'state': state,
+            'nonce': nonce
         }
 
         if self.is_public_client():
-            query_dict["code_challenge"] = create_sha256_code_challenge(code_verifier)
-            query_dict["code_challenge_method"] = "S256"
+            query_dict['code_challenge'] = create_sha256_code_challenge(code_verifier)
+            query_dict['code_challenge_method'] = 'S256'
 
         query = get_url_encode_from_dict(query_dict)
-        authorization_url = f"{self.authorize_uri}?{query}"
+        authorization_url = f'{self.authorize_uri}?{query}'
         return authorization_url, state, nonce, code_verifier
 
     def get_token(self, url, state, nonce=None, code_verifier=None):
         params = get_dict_from_url(url)
-        req_state = params["state"][0]
-        code = params["code"][0]
+        req_state = params['state'][0]
+        code = params['code'][0]
         if (state != req_state):
             raise StateInvalidException()
 
         body = {
-            "redirect_uri": self.redirect_uri,
-            "grant_type": "authorization_code",
-            "code": code
+            'redirect_uri': self.redirect_uri,
+            'grant_type': 'authorization_code',
+            'code': code
         }
 
         if code_verifier is not None:
-            body["code_verifier"] = code_verifier
-            body["client_id"] = self.client_id
+            body['code_verifier'] = code_verifier
+            body['client_id'] = self.client_id
             res = self.client.post(self.token_uri, data=body)
         else:
             res = self.client.post(self.token_uri, data=body, auth=(self.client_id, self.client_secret))
 
         data = res.json()
 
-        if "id_token" in data:
-            id_token = data["id_token"]
-            nonce_token = jwt.decode(id_token, verify=False, algorithms=["RSA256"]).get("nonce")
+        if 'id_token' in data:
+            id_token = data['id_token']
+            nonce_token = jwt.decode(id_token, verify=False, algorithms=['RS256']).get('nonce')
 
             if nonce != nonce_token:
-                raise NonceInvalidException(f"invalid nonce = {nonce}")
+                raise NonceInvalidException(f'invalid nonce = {nonce}')
 
         return res.json(), res.status_code
 
     def __decode_token(self, token):
-        kid = jwt.get_unverified_header(token).get("kid")
-        aud = jwt.decode(token, verify=False, algorithms=["RSA256"]).get("aud")
+        kid = jwt.get_unverified_header(token).get('kid')
+        aud = jwt.decode(token, verify=False, algorithms=['RS256']).get('aud')
 
-        if not hasattr(self, "public_keys") or kid not in self.public_keys:
+        if not hasattr(self, 'public_keys') or kid not in self.public_keys:
             self.__get_public_keys()
 
         pubkey = self.public_keys.get(kid)
-        payload = jwt.decode(token, key=pubkey, algorithms=["RS256"], audience=aud)
+        payload = jwt.decode(token, key=pubkey, algorithms=['RS256'], audience=aud)
 
         return payload
 
@@ -90,13 +90,13 @@ class CodeClientSDK(BaseClientSDK):
 
     def refresh_token(self, refresh_token):
         body = {
-            "grant_type": "refresh_token",
-            "refresh_token": refresh_token,
-            "scope": " ".join(self.scope),
+            'grant_type': 'refresh_token',
+            'refresh_token': refresh_token,
+            'scope': ' '.join(self.scope),
         }
 
         if self.is_public_client():
-            body["client_id"] = self.client_id
+            body['client_id'] = self.client_id
             res = self.client.post(self.refresh_token_uri, data=body)
         else:
             res = self.client.post(self.refresh_token_uri, data=body, auth=(self.client_id, self.client_secret))
