@@ -8,8 +8,8 @@ class CredentialsClientSDK(BaseClientSDK):
 
     def get_token(self):
         body = {
-            "grant_type": "client_credentials",
-            "scope": " ".join(self.scope)
+            'grant_type': 'client_credentials',
+            'scope': ' '.join(self.scope)
         }
         res = self.client.post(self.token_uri, auth=(self.client_id, self.client_secret), data=body)
         return res.json(), res.status_code
